@@ -1,7 +1,7 @@
 /*
  * Calcurse - text-based organizer
  *
- * Copyright (c) 2004-2022 calcurse Development Team <misc@calcurse.org>
+ * Copyright (c) 2004-2023 calcurse Development Team <misc@calcurse.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -207,14 +207,16 @@ void ui_todo_draw(int n, WINDOW *win, int y, int hilt, void *cb_data)
 	if (hilt)
 		custom_apply_attr(win, ATTR_HIGHEST);
 
-	if (utf8_strwidth(todo->mesg) < width) {
-		mesg = todo->mesg;
-	} else {
+	mesg = todo->mesg;
+	if (mesg[0] == '\0')
+		mesg = EMPTY_EVENT_DESC_DEFAULT;
+
+	if (utf8_strwidth(mesg) >= width) {
 		width -= 3;
-		for (j = 0; todo->mesg[j] && width > 0; j++) {
-			if (!UTF8_ISCONT(todo->mesg[j]))
-				width -= utf8_width(&todo->mesg[j]);
-			buf[j] = todo->mesg[j];
+		for (j = 0; mesg[j] && width > 0; j++) {
+			if (!UTF8_ISCONT(mesg[j]))
+				width -= utf8_width(&mesg[j]);
+			buf[j] = mesg[j];
 		}
 		if (j) {
 			buf[j - 1] = '.';
@@ -325,6 +327,11 @@ void ui_todo_popup_item(void)
 
 		asprintf(&notepath, "%s%s", path_notes, item->note);
 		fp = fopen(notepath, "r");
+		if (fp == NULL) {
+			item_in_popup(NULL, NULL, item->mesg, _("TODO:"));
+			return;
+		}
+
 		note_read_contents(note, note_size, fp);
 		fclose(fp);
 		mem_free(notepath);
