@@ -3,11 +3,12 @@
 . "${TEST_INIT:-./test-init.sh}"
 
 if [ "$1" = 'actual' ]; then
-  mkdir .calcurse || exit 1
-  cp "$DATA_DIR/conf" .calcurse || exit 1
-  "$CALCURSE" -D "$PWD/.calcurse" -i "$DATA_DIR/ical-005.ical"
-  "$CALCURSE" -D "$PWD/.calcurse" -s10/03/2013 -r3
-  rm -rf .calcurse || exit 1
+  tmpdir=$(mktemp -d)
+  cp "$DATA_DIR/conf" "$tmpdir" || exit 1
+  "$CALCURSE" -D "$tmpdir" -i "$DATA_DIR/ical-005.ical"
+  "$CALCURSE" -D "$tmpdir" -s10/03/2013 -r3
+  cat "$tmpdir/notes"/*
+  rm -rf "$tmpdir" || exit 1
 elif [ "$1" = 'expected' ]; then
   cat <<EOD
 Import process report: 0023 lines read
@@ -15,11 +16,13 @@ Import process report: 0023 lines read
 10/03/13:
  * All day
  * On day 1
- * On day 2
  * Two days
 
 10/04/13:
+ * On day 2
  * Two days
+-- 
+Import: multi-day event changed to one-day event
 EOD
 else
   ./run-test "$0"
